@@ -47,7 +47,7 @@ class WebDriverSingleton(WebDriver):
 
     @classmethod
     def _get_session_id(cls, kwargs):
-        logger.info(f"{inspect.currentframe().f_code.co_name}")
+        logger.debug(f"{inspect.currentframe().f_code.co_name}")
         res = requests.get(kwargs['command_executor'] + '/sessions')
         res_json = json.loads(res.text)
         sessions = res_json.get("value", [])
@@ -58,7 +58,7 @@ class WebDriverSingleton(WebDriver):
     @classmethod
     def clear_instance(cls):
         """Удаляет текущий экземпляр и очищает ресурсы WebDriverSingleton."""
-        logger.info(f"{inspect.currentframe().f_code.co_name}")
+        logger.debug(f"{inspect.currentframe().f_code.co_name}")
         cls._driver = None
         cls._instance = None  # Убирает ссылку на экземпляр для высвобождения памяти
         gc.collect()
@@ -72,7 +72,7 @@ class WebDriverSingleton(WebDriver):
             WebDriver
                 The current WebDriver instance.
         """
-        logger.info(f"{inspect.currentframe().f_code.co_name}")
+        logger.debug(f"{inspect.currentframe().f_code.co_name}")
         return cls._driver
 
 
@@ -143,7 +143,7 @@ class ShadowstepBase:
         Returns:
             None
         """
-        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         # if provided caps instead options, redeclare caps to options
         # see https://github.com/appium/appium-uiautomator2-driver
         if capabilities is not None and options is None:
@@ -415,7 +415,7 @@ class ShadowstepBase:
         Returns:
             None
         """
-        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         try:
             if self.driver:
                 response = requests.delete(f"{self.command_executor}/session/{self.driver.session_id}")
@@ -436,7 +436,7 @@ class ShadowstepBase:
         Returns:
             None
         """
-        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         self.disconnect()
         WebDriverSingleton.clear_instance()
         self.connect(command_executor=self.command_executor,
@@ -452,7 +452,7 @@ class ShadowstepBase:
         time.sleep(3)
 
     def is_connected(self) -> bool:
-        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         try:
             response = requests.get(f"{self.command_executor}/sessions")
             response_json = response.json().get("value", {})
